@@ -1,16 +1,17 @@
-from cosmoglobe.sky import components
-from cosmoglobe.sky import Model
-from cosmoglobe.utils import utils
+import inspect
+import pathlib
+import sys
 
 import astropy.units as u
 import h5py
 import healpy as hp
 import numpy as np
-import sys
-import inspect
-import pathlib
-from tqdm import tqdm
 from numba import njit
+from tqdm import tqdm
+
+from cosmoglobe.sky import components
+from cosmoglobe.sky import Model
+from cosmoglobe.utils import utils
 
 # Model parameter group name as implemented in commander
 param_group = 'parameters'
@@ -97,7 +98,7 @@ def model_from_chain(file, nside=None, samples='all', burn_in=None, comps=None):
             pbar.set_description(f'{comp:<{padding}}')
             comp = comp_from_chain(file, comp, comps[comp], 
                                      nside, samples)                                           
-            model._insert_component(comp)
+            model._add_component_to_model(comp)
             pbar.update(1)
 
         pbar.set_description('Done')
@@ -139,6 +140,7 @@ def comp_from_chain(file, component, component_class, model_nside, samples):
     freq_ref = (parameters['nu_ref']*u.Hz).to(u.GHz)
     fwhm_ref = (parameters['fwhm']*u.arcmin).to(u.rad)
     nside = parameters['nside']
+
     if parameters['polarization'] == 'True':
         comp_is_polarized = True
     else:
@@ -151,6 +153,7 @@ def comp_from_chain(file, component, component_class, model_nside, samples):
 
     # Getting arguments required to initialize component
     args_list = _get_comp_args(component_class) 
+
     args = {}
     if isinstance(samples, list) and len(samples) > 1:
         get_items = _get_averaged_items
@@ -169,6 +172,8 @@ def comp_from_chain(file, component, component_class, model_nside, samples):
                 map_names.append(arg)
             elif _item_exists(file, component, arg):
                 other_items_names.append(arg)
+            elif arg == 'nside':
+                args['nside'] = nside
             else:
                 raise KeyError(f'item {arg} is not present in the chain')
 
@@ -180,6 +185,7 @@ def comp_from_chain(file, component, component_class, model_nside, samples):
     maps_ = get_items(
         file, samples, component, [f'{map_}_map' for map_ in map_names]
     )
+
     maps = dict(zip(map_names, maps_))
     if maps:
         if model_nside is not None and nside != model_nside:
@@ -216,8 +222,8 @@ def comp_from_chain(file, component, component_class, model_nside, samples):
 
     args.update(alms)
     args['amp'] *= amp_unit
-    args = utils._set_spectral_units(args)
-    scalars = utils._extract_scalars(args) # dont save scalar maps
+    args = utils.set_spectral_units(args)
+    scalars = utils.extract_scalars(args) # dont save scalar maps
     args.update(scalars)
     if 'freq_ref' in args_list:
         if comp_is_polarized:
@@ -226,6 +232,9 @@ def comp_from_chain(file, component, component_class, model_nside, samples):
             freq = u.Quantity(freq_ref[0])
         args['freq_ref'] = freq
 
+    if component =='radio':
+       args['specind'] = args['specind'][0] # take alpha from chain
+
     return component_class(**args)
 
 
@@ -530,6 +539,7 @@ def model_from_h5(filename):
 
     filename = pathlib.Path(filename)
     model = Model()
+    nside = None
     with h5py.File(filename, 'r') as f:
         for comp in f:
             amp_dset = f.get(f'{comp}/amp')
@@ -554,9 +564,22 @@ def model_from_h5(filename):
                     unit=dset.attrs.get('unit', None)
                 )
 
+            if nside is None:
+                nside = hp.get_nside(amp)
+
             component = COSMOGLOBE_COMPS[comp]
-            model._insert_component(
-                component(amp=amp, freq_ref=freq_ref, **spectral_parameters)
-            )
+            if comp == 'radio':
+                model._add_component_to_model(
+                    component(
+                        amp=amp, 
+                        freq_ref=freq_ref, 
+                        nside=nside,
+                        **spectral_parameters
+                    )
+                )            
+            else:
+                model._add_component_to_model(
+                    component(amp=amp, freq_ref=freq_ref, **spectral_parameters)
+                )
 
     return model
\ No newline at end of file
